@@ -212,9 +212,9 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('compute/image_alt_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref_alt').with(:value => nil)
-          is_expected.to contain_tempest_config('compute/resize_available').with(:value => nil)
           is_expected.to contain_tempest_config('compute/build_interval').with(:value => nil)
           is_expected.to contain_tempest_config('compute-feature-enabled/attach_encrypted_volume').with(:value => false)
+          is_expected.to contain_tempest_config('compute-feature-enabled/resize').with(:value => false)
           is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('validation/run_validation').with(:value => false)
           is_expected.to contain_tempest_config('identity/admin_role').with(:value => nil)
@@ -235,8 +235,8 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => true)
           is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => true)
           is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => true)
+          is_expected.to contain_tempest_config('l2gw/l2gw_switch').with(:value => nil)
           is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => nil)
-          is_expected.to contain_tempest_config('network/l2gw_switch').with(:value => nil)
           is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
           is_expected.to contain_tempest_config('network/public_router_id').with(:value => '')
           is_expected.to contain_tempest_config('dashboard/login_url').with(:value => nil)
@@ -268,6 +268,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/congress').with(:value => false)
           is_expected.to contain_tempest_config('service_available/designate').with(:value => false)
           is_expected.to contain_tempest_config('service_available/octavia').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/barbican').with(:value => false)
           is_expected.to contain_tempest_config('whitebox/db_uri').with(:value => nil)
           is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
           is_expected.to contain_tempest_config('oslo_concurrency/lock_path').with(:value => '/var/lib/tempest')
@@ -406,8 +407,8 @@ describe 'tempest' do
         it { expect { is_expected.to contain_package('python-neutron-fwaas-tests') } }
         it { expect { is_expected.to contain_package('python-neutron-lbaas-tests') } }
         it { expect { is_expected.to contain_package('python-neutron-vpnaas-tests') } }
-        it { expect { is_expected.to contain_package('python-networking-bgpvpn-tests') } }
-        it { expect { is_expected.to contain_package('python-networking-l2gw-tests') } }
+        it { expect { is_expected.to contain_package('python-networking-bgpvpn-tests-tempest') } }
+        it { expect { is_expected.to contain_package('python-networking-l2gw-tests-tempest') } }
         it { expect { is_expected.to contain_package('python-horizon-tests-tempest') } }
       end
     end
